# Typing module

## Aliases

```python
from typing import Any

from numpy.typing import NDArray

type Array = NDArray[Any]

type Vector = NDArray[Any]
type Matrix = NDArray[Any]
type SquareMatrix = NDArray[Any]
```

---

## Predicates
::: pqlattice.typing.is_Vector

::: pqlattice.typing.is_Matrix

::: pqlattice.typing.is_SquareMatrix
